# Generated by Django 4.2.4 on 2023-12-22 15:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='amount',
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='currency',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
    ]
