# Generated by Django 4.2.21 on 2025-05-23 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0006_remove_payment_settled_remove_payment_settled_at_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Plan',
            fields=[
                ('plan_id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=512)),
                ('alternative_name', models.CharField(blank=True, max_length=512, null=True)),
                ('reference', models.CharField(blank=True, max_length=512, null=True)),
                ('interval', models.CharField(blank=True, max_length=50, null=True)),
                ('interval_count', models.IntegerField(blank=True, null=True)),
                ('amount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('currency', models.CharField(blank=True, max_length=10, null=True)),
                ('trial_period_days', models.IntegerField(blank=True, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('enabled', models.BooleanField(default=False)),
                ('private', models.BooleanField(default=False)),
                ('electronic_only', models.BooleanField(default=True)),
            ],
        ),
    ]
