# Generated by Django 4.2.9 on 2024-01-09 09:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0005_payment_user'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='payment',
            name='settled',
        ),
        migrations.RemoveField(
            model_name='payment',
            name='settled_at',
        ),
        migrations.AddField(
            model_name='payment',
            name='state',
            field=models.CharField(choices=[('pending', 'Pending'), ('settled', 'Settled'), ('failed', 'Failed'), ('retrying', 'Retrying'), ('refunded', 'Refunded')], default='pending', max_length=20),
        ),
        migrations.AddField(
            model_name='payment',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]
